EDIFF :: processing of powder electron diffraction patterns
-----------------------------------------------------------

* *MCREEP* is a Python package that...
	- Blah...
	- Blah...

Documentation, help and examples
--------------------------------

More detailed help, demo and source code including documentation are in
[GitHub](https://mirekslouf.github.io/mcreep).

Versions of MCREEP
------------------

* Version 0.1 = not-completely-finalized, but working
